@@ -888,8 +888,7 @@ impl App {
 
         #[cfg(unix)]
         let _server = con
-            .launch_args
-            .listen
+            .server_name
             .as_ref()
             .map(|server_name| {
                 let shared_root = Arc::new(Mutex::new(app_state.root.clone()));
@@ -999,6 +998,12 @@ impl App {
             }
         }
         terminal::reset_title(w, con);
+        kitty::manager()
+            .lock()
+            .unwrap()
+            .erase_images_before(w, usize::MAX)?;
+        w.flush()?;
+
         Ok(self.launch_at_end.take())
     }
 }
