@@ -36,6 +36,7 @@ pub enum CmdResult {
     ClosePanel {
         validate_purpose: bool,
         panel_ref: PanelReference,
+        clear_cache: bool,
     },
     ChangeLayout(LayoutInstruction),
     DisplayError(String),
@@ -75,7 +76,8 @@ impl CmdResult {
         match os {
             Ok(os) => {
                 if in_new_panel {
-                    CmdResult::NewPanel { // TODO keep the message ?
+                    CmdResult::NewPanel {
+                        // TODO keep the message ?
                         state: Box::new(os),
                         purpose: PanelPurpose::None,
                         direction: HDir::Right,
@@ -92,7 +94,10 @@ impl CmdResult {
         }
     }
     pub fn new_state(state: Box<dyn PanelState>) -> Self {
-        Self::NewState { state, message: None }
+        Self::NewState {
+            state,
+            message: None,
+        }
     }
     pub fn error<S: Into<String>>(message: S) -> Self {
         Self::DisplayError(message.into())
@@ -106,7 +111,10 @@ impl From<Launchable> for CmdResult {
 }
 
 impl fmt::Debug for CmdResult {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+    fn fmt(
+        &self,
+        f: &mut fmt::Formatter,
+    ) -> fmt::Result {
         write!(
             f,
             "{}",
@@ -114,13 +122,15 @@ impl fmt::Debug for CmdResult {
                 CmdResult::ApplyOnPanel { .. } => "ApplyOnPanel",
                 CmdResult::ChangeLayout(_) => "ChangeLayout",
                 CmdResult::ClosePanel {
-                    validate_purpose: false, ..
+                    validate_purpose: false,
+                    ..
                 } => "CancelPanel",
                 CmdResult::ClosePanel {
-                    validate_purpose: true, ..
+                    validate_purpose: true,
+                    ..
                 } => "OkPanel",
                 CmdResult::DisplayError(_) => "DisplayError",
-                CmdResult::ExecuteSequence{ .. } => "ExecuteSequence",
+                CmdResult::ExecuteSequence { .. } => "ExecuteSequence",
                 CmdResult::Keep => "Keep",
                 CmdResult::Message { .. } => "Message",
                 CmdResult::Launch(_) => "Launch",
