@@ -3,9 +3,13 @@ use {
     crate::{
         app::{
             AppContext,
+            PanelStateType,
             SelInfo,
         },
-        path::{self, PathAnchor},
+        path::{
+            self,
+            PathAnchor,
+        },
         syntactic::SYNTAX_THEMES,
         verb::{
             ArgDef,
@@ -20,7 +24,10 @@ use {
 };
 
 /// find the longest common start of a and b
-fn common_start<'l>(a: &'l str, b: &str) -> &'l str {
+fn common_start<'l>(
+    a: &'l str,
+    b: &str,
+) -> &'l str {
     let l = a.len().min(b.len());
     for i in 0..l {
         if a.as_bytes()[i] != b.as_bytes()[i] {
@@ -33,7 +40,6 @@ fn common_start<'l>(a: &'l str, b: &str) -> &'l str {
 /// how an input can be completed
 #[derive(Debug)]
 pub enum Completions {
-
     /// no completion found
     None,
 
@@ -52,7 +58,9 @@ impl Completions {
         let mut iter = completions.iter();
         let mut common: &str = match iter.next() {
             Some(s) => s,
-            _ => { return Self::None; }
+            _ => {
+                return Self::None;
+            }
         };
         for c in iter {
             common = common_start(common, c);
@@ -62,7 +70,6 @@ impl Completions {
         } else {
             Self::Common(common.to_string())
         }
-
     }
 
     /// the wholes are assumed to all start with start.
@@ -70,8 +77,9 @@ impl Completions {
         start: &str,
         wholes: Vec<&str>,
     ) -> Self {
-        let completions = wholes.iter()
-            .map(|w|
+        let completions = wholes
+            .iter()
+            .map(|w| {
                 if let Some(stripped) = w.strip_prefix(start) {
                     stripped
                 } else {
@@ -79,7 +87,7 @@ impl Completions {
                     warn!("unexpected non completing whole: {:?}", w);
                     *w
                 }
-            )
+            })
             .map(|c| c.to_string())
             .collect();
         Self::from_list(completions)
@@ -89,8 +97,12 @@ impl Completions {
         start: &str,
         con: &AppContext,
         sel_info: SelInfo<'_>,
+        panel_state_type: Option<PanelStateType>,
     ) -> Self {
-        match con.verb_store.search(start, Some(sel_info), false) {
+        match con
+            .verb_store
+            .search(start, Some(sel_info), false, panel_state_type)
+        {
             PrefixSearchResult::NoMatch => Self::None,
             PrefixSearchResult::Match(name, _) => {
                 if start.len() >= name.len() {
@@ -100,10 +112,7 @@ impl Completions {
                     Self::Common(name[start.len()..].to_string())
                 }
             }
-            PrefixSearchResult::Matches(completions) => Self::for_wholes(
-                start,
-                completions,
-            ),
+            PrefixSearchResult::Matches(completions) => Self::for_wholes(start, completions),
         }
     }
 
@@ -113,8 +122,12 @@ impl Completions {
         path: &Path,
         sel_info: SelInfo<'_>,
         con: &AppContext,
+        panel_state_type: Option<PanelStateType>,
     ) -> io::Result<Vec<String>> {
-        let anchor = match con.verb_store.search(verb_name, Some(sel_info), false) {
+        let anchor = match con
+            .verb_store
+            .search(verb_name, Some(sel_info), false, panel_state_type)
+        {
             PrefixSearchResult::Match(_, verb) => verb.get_unique_arg_anchor(),
             _ => PathAnchor::Unspecified,
         };
@@ -122,7 +135,10 @@ impl Completions {
         let parent = path::path_from(path, anchor, parent_part);
         let mut children = Vec::new();
         if !parent.exists() {
-            debug!("no path completion possible because {:?} doesn't exist", &parent);
+            debug!(
+                "no path completion possible because {:?} doesn't exist",
+                &parent
+            );
         } else {
             for entry in parent.read_dir()? {
                 let entry = entry?;
@@ -143,13 +159,13 @@ impl Completions {
         Ok(children)
     }
 
-
     /// we have a verb, we try to complete one of the args
     fn for_arg(
         verb_name: &str,
         arg: &str,
         con: &AppContext,
         sel_info: SelInfo<'_>,
+        panel_state_type: Option<PanelStateType>,
     ) -> Self {
         if arg.contains(' ') {
             return Self::None;
@@ -157,20 +173,18 @@ impl Completions {
         // we try to get the type of argument
         let arg_def = con
             .verb_store
-            .search_sel_info_unique(verb_name, sel_info)
+            .search_sel_info_unique(verb_name, sel_info, panel_state_type)
             .and_then(|verb| verb.invocation_parser.as_ref())
             .and_then(|invocation_parser| invocation_parser.get_unique_arg_def());
         if matches!(arg_def, Some(ArgDef::Theme)) {
             Self::for_theme_arg(arg)
         } else {
-            Self::for_path_arg(verb_name, arg, con, sel_info)
+            Self::for_path_arg(verb_name, arg, con, sel_info, panel_state_type)
         }
     }
 
     /// we have a verb and it asks for a theme
-    fn for_theme_arg(
-        arg: &str,
-    ) -> Self {
+    fn for_theme_arg(arg: &str) -> Self {
         let arg = arg.to_lowercase();
         let completions: Vec<String> = SYNTAX_THEMES
             .iter()
@@ -186,6 +200,7 @@ impl Completions {
         arg: &str,
         con: &AppContext,
         sel_info: SelInfo<'_>,
+        panel_state_type: Option<PanelStateType>,
     ) -> Self {
         // in the future we might offer completion of other types
         // of arguments, maybe user supplied, but there's no use case
@@ -196,7 +211,8 @@ impl Completions {
         match &sel_info {
             SelInfo::None => Self::None,
             SelInfo::One(sel) => {
-                match Self::list_for_path(verb_name, arg, sel.path, sel_info, con) {
+                match Self::list_for_path(verb_name, arg, sel.path, sel_info, con, panel_state_type)
+                {
                     Ok(list) => Self::from_list(list),
                     Err(e) => {
                         warn!("Error while trying to complete path: {:?}", e);
@@ -207,17 +223,9 @@ impl Completions {
             SelInfo::More(stage) => {
                 // We're looking for the possible completions which
                 // are valid for all elements of the stage
-                let mut lists = stage.paths()
-                    .iter()
-                    .filter_map(|path| {
-                        Self::list_for_path(
-                                verb_name,
-                                arg,
-                                path,
-                                sel_info,
-                                con
-                        ).ok()
-                    });
+                let mut lists = stage.paths().iter().filter_map(|path| {
+                    Self::list_for_path(verb_name, arg, path, sel_info, con, panel_state_type).ok()
+                });
                 let mut list = match lists.next() {
                     Some(list) => list,
                     None => {
@@ -241,17 +249,18 @@ impl Completions {
         parts: &CommandParts,
         con: &AppContext,
         sel_info: SelInfo<'_>,
+        panel_state_type: Option<PanelStateType>,
     ) -> Self {
         match &parts.verb_invocation {
             Some(invocation) if !invocation.is_empty() => {
                 match &invocation.args {
                     None => {
                         // looking into verb completion
-                        Self::for_verb(&invocation.name, con, sel_info)
+                        Self::for_verb(&invocation.name, con, sel_info, panel_state_type)
                     }
                     Some(args) if !args.is_empty() => {
                         // looking into arg completion
-                        Self::for_arg(&invocation.name, args, con, sel_info)
+                        Self::for_arg(&invocation.name, args, con, sel_info, panel_state_type)
                     }
                     _ => {
                         // nothing possible
@@ -262,5 +271,4 @@ impl Completions {
             _ => Self::None, // no possible completion if no verb invocation
         }
     }
-
 }
