@@ -13,6 +13,7 @@ use {
             ConfError,
             ProgramError,
         },
+        kitty::KittyGraphicsDisplay,
         kitty::TransmissionMedium,
         path::{
             PathAnchor,
@@ -108,6 +109,9 @@ pub struct Conf {
     #[serde(alias = "kitty-graphics-transmission")]
     pub kitty_graphics_transmission: Option<TransmissionMedium>,
 
+    #[serde(alias = "kitty-graphics-display")]
+    pub kitty_graphics_display: Option<KittyGraphicsDisplay>,
+
     #[serde(default, alias = "kept-kitty-temp-files")]
     pub kept_kitty_temp_files: Option<NonZeroUsize>,
 
@@ -256,6 +260,7 @@ impl Conf {
         overwrite!(self, update_work_dir, conf);
         overwrite!(self, enable_kitty_keyboard, conf);
         overwrite!(self, kitty_graphics_transmission, conf);
+        overwrite!(self, kitty_graphics_display, conf);
         overwrite!(self, kept_kitty_temp_files, conf);
         overwrite!(self, lines_after_match_in_preview, conf);
         overwrite!(self, lines_before_match_in_preview, conf);
