@@ -2,7 +2,6 @@
 
 use {
     custom_error::custom_error,
-    image::error::ImageError,
     lazy_regex::regex,
     std::io,
 };
@@ -12,7 +11,7 @@ custom_error! {pub ProgramError
     ArgParse {bad: String, valid: String} = "{bad:?} can't be parsed (valid values: {valid:?})",
     ConfFile {path:String, details: ConfError} = "Bad configuration file {path:?} : {details}",
     Conf {source: ConfError} = "Bad configuration: {source}",
-    ImageError {source: ImageError } = "{source}",
+    ImageError {details: String} = "Image error: {details}",
     InternalError {details: String} = "Internal error: {details}", // should not happen
     Io {source: io::Error} = "IO Error : {source}",
     LaunchError {program: String, source: io::Error} = "Unable to launch {program}: {source}",
