@@ -1,10 +1,8 @@
-use {
-    crate::{
-        app::AppContext,
-        keys,
-        pattern::*,
-        verb::*,
-    },
+use crate::{
+    app::AppContext,
+    keys,
+    pattern::*,
+    verb::*,
 };
 
 /// what should be shown for a verb in the help screen, after
@@ -46,7 +44,7 @@ pub fn matching_verb_rows<'v>(
     con: &'v AppContext,
 ) -> Vec<MatchingVerbRow<'v>> {
     let mut rows = Vec::new();
-    for verb in con.verb_store.verbs().iter() {
+    for verb in con.verb_store.verbs() {
         if !verb.show_in_doc {
             continue;
         }
@@ -73,9 +71,7 @@ pub fn matching_verb_rows<'v>(
         let keys_desc = verb
             .keys
             .iter()
-            .filter(|&&k| {
-                con.modal || !keys::is_key_only_modal(k)
-            })
+            .filter(|&&k| con.modal || !keys::is_key_only_modal(k))
             .map(|&k| keys::KEY_FORMAT.to_string(k))
             .collect::<Vec<String>>() // no way to join an iterator today ?
             .join(", ");
