@@ -1,14 +1,18 @@
 mod detect_support;
 mod image_renderer;
+mod terminal_esc;
 
 pub use image_renderer::*;
 
+use crate::display::cell_size_in_pixels;
+
 use {
     crate::{
         app::AppContext,
         display::W,
         errors::ProgramError,
         image::SourceImage,
+        kitty::detect_support::is_tmux,
     },
     crokey::crossterm::style::Color,
     once_cell::sync::Lazy,
@@ -78,8 +82,10 @@ impl KittyManager {
             return self.renderer_if_tested();
         }
         let options = KittyImageRendererOptions {
+            display: con.kitty_graphics_display,
             transmission_medium: con.kitty_graphics_transmission,
             kept_temp_files: con.kept_kitty_temp_files,
+            is_tmux: is_tmux(),
         };
         match KittyImageRenderer::new(options) {
             Some(renderer) => {
@@ -115,7 +121,10 @@ impl KittyManager {
         con: &AppContext,
     ) -> Result<Option<KittyImageId>, ProgramError> {
         if let Some(renderer) = self.renderer(con) {
-            let img = src.optimal()?;
+            let (cell_width, cell_height) = cell_size_in_pixels()?;
+            let area_width = area.width as u32 * cell_width;
+            let area_height = area.height as u32 * cell_height;
+            let img = src.fitting(area_width, area_height, None)?;
             let new_id = renderer.print(w, &img, src_path, area, bg)?;
             self.rendered_images.push(RenderedImage {
                 image_id: new_id,
@@ -132,13 +141,28 @@ impl KittyManager {
         drawing_count: usize,
     ) -> Result<(), ProgramError> {
         let mut kept_images = Vec::new();
+        let is_tmux = detect_support::is_tmux();
+        let tmux_nest_count = if is_tmux {
+            detect_support::get_tmux_nest_count()
+        } else {
+            0
+        };
+        let tmux_header = is_tmux.then_some(terminal_esc::get_tmux_header(tmux_nest_count));
+        let tmux_tail = is_tmux.then_some(terminal_esc::get_tmux_tail(tmux_nest_count));
+        let esc = terminal_esc::get_esc_seq(tmux_nest_count);
         for image in self.rendered_images.drain(..) {
             if image.drawing_count >= drawing_count {
                 kept_images.push(image);
             } else {
                 let id = image.image_id;
-                debug!("erase kitty image {}", id);
-                write!(w, "\u{1b}_Ga=d,d=I,i={id}\u{1b}\\")?;
+                debug!("erase kitty image {id}");
+                if let Some(s) = &tmux_header {
+                    write!(w, "{s}")?;
+                }
+                write!(w, "{}_Ga=d,d=I,i={}{}\\", &esc, id, &esc)?;
+                if let Some(s) = &tmux_tail {
+                    write!(w, "{s}")?;
+                }
             }
         }
         self.rendered_images = kept_images;
